<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ro">
<context>
    <name>Application</name>
    <message>
        <location filename="../../src/apps/dde-cooperation/main.cpp" line="50"/>
        <source>Cooperation</source>
        <translation>Colaborare</translation>
    </message>
    <message>
        <location filename="../../src/apps/dde-cooperation/main.cpp" line="54"/>
        <source>Cooperation is a powerful cross-terminal office tool that helps you deliver files, share keys and mice, and share clipboards between different devices.</source>
        <translation>Colaborare este un instrument puternic de birou inter-terminal care vă ajută să transmiteți fișiere, să împărțiți tastatură și mouse, și să împărțiți panourile de clipboard între dispozitive diferite.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/cooperationplugin.cpp" line="69"/>
        <source>File transfer settings</source>
        <translation>Setările de transfer de fișiere</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/cooperationplugin.cpp" line="71"/>
        <source>Settings</source>
        <comment>button</comment>
        <translation>Setări</translation>
    </message>
</context>
<context>
    <name>cooperation_core::BottomLabel</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="341"/>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="373"/>
        <source>Local IP: %1</source>
        <translation>IP local: %1</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ConfirmWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="25"/>
        <source>&quot;%1&quot; send some files to you</source>
        <translation>&quot;%1&quot; trimite unii fișiere către tine</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="34"/>
        <source>Reject</source>
        <comment>button</comment>
        <translation>Respinge</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="35"/>
        <source>Accept</source>
        <comment>button</comment>
        <translation>Acceptă</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationSearchEdit</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/win/cooperationsearchedit.cpp" line="34"/>
        <source>Search</source>
        <translation>Caută</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationTaskDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="111"/>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="131"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anulează</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="134"/>
        <source>Retry</source>
        <comment>button</comment>
        <translation>Încearcă din nou</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="157"/>
        <source>Reject</source>
        <comment>button</comment>
        <translation>Respinge</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="160"/>
        <source>Accept</source>
        <comment>button</comment>
        <translation>Acceptă</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="184"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Închide</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationTransDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="275"/>
        <source>File Transfer</source>
        <translation>Transfer de fișiere</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="278"/>
        <source>File transfer</source>
        <translation>Transfer de fișiere</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationUtil</name>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="217"/>
        <source>View Help Manual</source>
        <translation>Vezi Manualul de Ajutor</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="218"/>
        <source>Welcome to dde-cooperation</source>
        <translation>Bun venit în dde-cooperation</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="222"/>
        <source>Keyboard and mouse sharing</source>
        <translation>Împărțirea tastaturii și a mouse-ului</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="222"/>
        <source>When a connection is made between two devices, the initiator&apos;s keyboard and mouse can be used to control the other device</source>
        <translation>Când se stabilește o conexiune între două dispozitive, tastatura și mouse-ul inițiatorului pot fi folosite pentru a controla celălalt dispozitiv</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="224"/>
        <source>Clipboard sharing</source>
        <translation>Împărțirea clipboard-ului</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="224"/>
        <source>Once a connection is made between two devices, the clipboard will be shared and can be copied on one device and pasted on the other device</source>
        <translation>După ce se stabilește o conexiune între două dispozitive, clipboard-ul va fi împărțit și poate fi copiat pe unul și lipit pe celălalt dispozitiv</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="226"/>
        <source>Delivery of documents</source>
        <translation>Livrarea documentelor</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="226"/>
        <source>After connecting between two devices, you can initiate a file delivery to the other device</source>
        <translation>După ce se stabilește o conexiune între două dispozitive, poți iniția o livrare de fișiere către celălalt dispozitiv</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="228"/>
        <source>For detailed instructions, please click on the Help Manual below</source>
        <translation>Pentru instrucțiuni detaliate, apasă pe Manualul de Ajutor de mai jos</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="228"/>
        <source>Usage</source>
        <translation>Utilizare</translation>
    </message>
</context>
<context>
    <name>cooperation_core::DeviceItem</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/deviceitem.cpp" line="191"/>
        <source>connected</source>
        <translation>conectat</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/deviceitem.cpp" line="197"/>
        <source>connectable</source>
        <translation>conectabil</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/deviceitem.cpp" line="204"/>
        <source>offline</source>
        <translation>offline</translation>
    </message>
</context>
<context>
    <name>cooperation_core::DiscoverController</name>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="245"/>
        <source>Confirm</source>
        <translation>Confirma</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="246"/>
        <source>Close</source>
        <translation>Închis</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="248"/>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="257"/>
        <source>Please click to confirm to enable the LAN discovery service!</source>
        <translation>Vă rugăm să faceți clic pentru a confirma activarea serviciului de descoperire LAN!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="249"/>
        <source>Unable to discover and be discovered by other devices when LAN discovery service is not turned on</source>
        <translation>Nedezvoltat să descoperiți și să fiți descoperiți de alte dispozitive atunci când serviciul de descoperire LAN nu este activat</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="258"/>
        <source>Unable to discover and be discovered by other devices when LAN discovery service is not turned onRight click on Windows Start menu -&gt;Computer Management -&gt;Services and Applications -&gt;Services to enable Bonjour service</source>
        <translation>Nedezvoltat să descoperiți și să fiți descoperiți de alte dispozitive atunci când serviciul de descoperire LAN nu este activat. Faceți clic dreapta pe meniul Windows Start -&gt;Computer Management -&gt;Services and Applications -&gt;Services pentru a activa serviciul Bonjour</translation>
    </message>
</context>
<context>
    <name>cooperation_core::FirstTipWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="126"/>
        <source>First step</source>
        <translation>Primul pas</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="127"/>
        <source>The opposite end opens the application and connects to the same network</source>
        <translation>Partea opusă deschide aplicația și se conectează la aceeași rețea</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="128"/>
        <source>Second step</source>
        <translation>Al doilea pas</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="130"/>
        <source>Third step</source>
        <translation>Al treilea pas</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="189"/>
        <source>to send the file</source>
        <translation>pentru a trimite fișierul</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="196"/>
        <source>to connect to the peer device</source>
        <translation>pentru a vă conecta la dispozitivul pereche</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="129"/>
        <source>Enter the peer IP in the search box</source>
        <translation>Introduceți IP-ul pereche în caseta de căutare</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="131"/>
        <source>Click</source>
        <translation>Faceți clic</translation>
    </message>
</context>
<context>
    <name>cooperation_core::InformationDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="153"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="158"/>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="166"/>
        <source>the file save location is invalid</source>
        <translation>locul de salvare al fișierului este invalid</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="172"/>
        <source>This path is a read-only directory. Please choose a different location for saving the file.</source>
        <translation>Această cale este un director doar pentru citire. Vă rugăm să alegeți un alt loc pentru a salva fișierul.</translation>
    </message>
</context>
<context>
    <name>cooperation_core::LockScreenWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/screenmirroringwindow.cpp" line="204"/>
        <source>The current device has been locked</source>
        <translation>Dispozitivul curent a fost blocat</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/screenmirroringwindow.cpp" line="207"/>
        <source>You can unlock it on mobile devices</source>
        <translation>Poți debloca pe dispozitive mobile</translation>
    </message>
</context>
<context>
    <name>cooperation_core::LookingForDeviceWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="81"/>
        <source>Looking for devices</source>
        <translation>Caută dispozitive</translation>
    </message>
</context>
<context>
    <name>cooperation_core::MainWindow</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="266"/>
        <source>Minimise to system tray</source>
        <translation>Minimize în panou de sistem</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="268"/>
        <source>Exit</source>
        <translation>Ieșire</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="277"/>
        <source>No more enquiries</source>
        <translation>Nici o altă întrebare</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="285"/>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="296"/>
        <source>Cancel</source>
        <translation>Anulare</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="286"/>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="295"/>
        <source>Confirm</source>
        <translation>Confirma</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="287"/>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="294"/>
        <source>Please select your operation</source>
        <translation>Vă rugăm să selectați operațiunea dvs.</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="338"/>
        <source>Restore</source>
        <translation>Restaura</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="339"/>
        <source>Quit</source>
        <translation>Ieșire</translation>
    </message>
</context>
<context>
    <name>cooperation_core::MainWindowPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="62"/>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="63"/>
        <source>Phone</source>
        <translation>Telefon</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="74"/>
        <source>Selection of delivery device</source>
        <translation>Alegerea dispozitivului de livrare</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="84"/>
        <location filename="../../src/lib/cooperation/core/gui/win/mainwindow_p_win.cpp" line="126"/>
        <source>Settings</source>
        <translation>Setări</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="88"/>
        <source>Download client</source>
        <translation>Descarcă clientul</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/win/mainwindow_p_win.cpp" line="130"/>
        <source>Download Windows client</source>
        <translation>Descarcă clientul Windows</translation>
    </message>
</context>
<context>
    <name>cooperation_core::NoNetworkWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="150"/>
        <source>Please connect to the network</source>
        <translation>Vă rugăm să vă conectați la rețea</translation>
    </message>
</context>
<context>
    <name>cooperation_core::NoResultTipWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="185"/>
        <source>1. Enable cross-end collaborative applications. Applications on the UOS can be downloaded from the App Store, and applications on the Windows side can be downloaded from: </source>
        <translation>1. Activați aplicațiile colaborative pe mai multe dispozitive. Aplicațiile de pe UOS pot fi descărcate din App Store, iar aplicațiile de pe partea Windows pot fi descărcate de la: </translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="199"/>
        <source>2. On the same LAN as the device</source>
        <translation>2. Pe aceeași rețea LAN ca dispozitivul</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="204"/>
        <source>3. File Manager-Settings-File Drop-Allow the following users to drop files to me -&quot;Everyone on the same LAN&quot;</source>
        <translation>3. File Manager-Settings-File Drop-Permiteți următoarelor utilizatori să arunce fișiere către mine -&quot;Toți din aceeași rețea LAN&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="206"/>
        <source>3. Settings-Basic Settings-Discovery Mode-&quot;Allow everyone in the same LAN&quot;</source>
        <translation>3. Settings-Basic Settings-Discovery Mode-&quot;Permiteți toți din aceeași rețea LAN&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="212"/>
        <source>4. Try entering the target device IP in the top search box</source>
        <translation>4. Încercați să introduceți IP-ul dispozitivului țintă în caseta de căutare de sus</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="216"/>
        <source>Unable to find collaborative device？</source>
        <translation>Nu se poate găsi dispozitivul colaborativ?</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="245"/>
        <source>1. The mobile phone needs to download cross end collaborative applications.</source>
        <translation>1. Telefonul mobil trebuie să descarce aplicații colaborative pe mai multe dispozitive.</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="246"/>
        <source>Go to download&gt;</source>
        <translation>Mergeți la descărcare&gt;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="250"/>
        <source>2. After installation, scan the code to connect to this device for collaboration.</source>
        <translation>2. După instalare, scanati codul pentru a vă conecta la acest dispozitiv pentru colaborare.</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="251"/>
        <source>3. After connecting this device, the mobile end needs to keep cross end collaborative applications open and on the same LAN as this device</source>
        <translation>3. După ce vă conectați la acest dispozitiv, partea mobilă trebuie să mențină aplicațiile colaborative pe mai multe dispozitive deschise și pe aceeași rețea LAN ca acesta</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="253"/>
        <source>Instructions for use</source>
        <translation>Instrucțiuni de utilizare</translation>
    </message>
</context>
<context>
    <name>cooperation_core::NoResultWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="293"/>
        <source>No device found</source>
        <translation>Niciun dispozitiv găsit</translation>
    </message>
</context>
<context>
    <name>cooperation_core::PhoneHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="65"/>
        <source>Disconnect</source>
        <translation>Deconectare</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="93"/>
        <source>“%1”apply to initiate screen casting</source>
        <translation>„%1” se aplică pentru a iniția afișarea pe ecran</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="95"/>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="212"/>
        <source>cancel</source>
        <translation>anulează</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="96"/>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="157"/>
        <source>comfirm</source>
        <translation>confirmă</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="139"/>
        <source>“%1”connection disconnected!</source>
        <translation>„%1” conexiune deconectată!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="210"/>
        <source>Are you sure to disconnect and collaborate with &apos;%1&apos;?</source>
        <translation>Sigur doriți să deconectați și colaborați cu &apos;%1&apos;?</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="213"/>
        <source>disconnect</source>
        <translation>deconectare</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ProgressWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="115"/>
        <source>Remaining time %1 | %2%</source>
        <translation>Timp rămas %1 | %2%</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="133"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anulare</translation>
    </message>
</context>
<context>
    <name>cooperation_core::QRCodeWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="102"/>
        <source>Scan code connection</source>
        <translation>Conexiune prin scanare cod</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="108"/>
        <source>Please use the cross end collaboration app to scan the code</source>
        <translation>Vă rugăm să folosiți aplicația de colaborare pe mai multe dispozitive pentru a scană codul</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="114"/>
        <source>Mobile phones and devices need to be connected to the same local area network</source>
        <translation>Telefoanele mobile și dispozitivele trebuie să fie conectate la aceeași rețea locală</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="147"/>
        <source>Click to download UOS assistant APP</source>
        <translation>Faceți clic pentru a descărca aplicația UOS assistant</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ResultWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="179"/>
        <source>Ok</source>
        <comment>button</comment>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="182"/>
        <source>View</source>
        <comment>button</comment>
        <translation>Vizualizare</translation>
    </message>
</context>
<context>
    <name>cooperation_core::SettingDialogPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="47"/>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="53"/>
        <source>Everyone in the same LAN</source>
        <translation>Toți din același LAN</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="49"/>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="55"/>
        <source>Not allow</source>
        <translation>Nu este permis</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="50"/>
        <source>Screen right</source>
        <translation>Ecranul dreapta</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="51"/>
        <source>Screen left</source>
        <translation>Ecranul stânga</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="54"/>
        <source>Only those who are collaborating are allowed</source>
        <translation>Doar cei care colaborează sunt permisi</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="132"/>
        <source>Basic Settings</source>
        <translation>Setări de bază</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="143"/>
        <source>Discovery mode</source>
        <translation>Mod de descoperire</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="145"/>
        <source>Other devices can discover and connect with you through the &quot;Cooperation&quot; app</source>
        <translation>Alte dispozitive pot descoperi și să se conecteze la voi prin aplicația &quot;Cooperation&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="195"/>
        <source>Device name</source>
        <translation>Numele dispozitivului</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="213"/>
        <source>Peripheral share</source>
        <translation>Partajare periferice</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="215"/>
        <source>Allows peripherals that have been established to collaborate across devices to control this device, including keyboard, mouse, trackpad, etc</source>
        <translation>Permite perifericelor care au fost stabilite pentru a colabora între dispozitive să controleze acest dispozitiv, inclusiv tastatură, mouse, trackpad, etc</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="224"/>
        <source>When this device is the connected party, the mouse penetrates from the screen of this device to the position of the connected party</source>
        <translation>Când acest dispozitiv este partea conectată, mouse-ul pătrunde din ecranul acestui dispozitiv în poziția partii conectate</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="254"/>
        <source>Connection direction</source>
        <translation>Direcția conexiunii</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="273"/>
        <source>Allows the following users to send files to me</source>
        <translation>Permite utilizatorilor următori să trimită fișiere către mine</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="280"/>
        <source>File save location</source>
        <translation>Locația salvării fișierelor</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="296"/>
        <source>Share clipboard</source>
        <translation>Partajare Clipboard</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="298"/>
        <source>When sharing is enabled on the server (the connected device), the clipboard will be shared between the two computers</source>
        <translation>Când partajarea este activată pe server (dispozitivul conectat), clipboard-ul va fi partajat între cele două computere</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="355"/>
        <source>The device name must contain 1 to 20 characters</source>
        <translation>Numele dispozitivului trebuie să conțină între 1 și 20 de caractere</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="362"/>
        <source>The device name must contain 1 to 63 characters</source>
        <translation>Numele dispozitivului trebuie să conțină între 1 și 63 de caractere</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ShareHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="238"/>
        <source>connect</source>
        <translation>Conectare</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="246"/>
        <source>Disconnect</source>
        <translation>Deconectare</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="263"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="392"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="448"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="458"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="511"/>
        <source>Unable to collaborate to &quot;%1&quot;</source>
        <translation>Nu se poate colabora cu &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="265"/>
        <source>You are connecting to another device</source>
        <translation>Vă conectați la un alt dispozitiv</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="280"/>
        <source>Requesting collaborate to &quot;%1&quot;</source>
        <translation>Se cere colaborarea cu &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="307"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="483"/>
        <source>Coordination with &quot;%1&quot; has ended</source>
        <translation>Coordonarea cu &quot;%1&quot; s-a terminat</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="353"/>
        <source>A cross-end collaboration request was received from &quot;%1&quot;</source>
        <translation>A fost primita o cerere de colaborare inter-dispozitive de la &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="354"/>
        <source>Reject</source>
        <translation>Respinge</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="355"/>
        <source>Accept</source>
        <translation>Acceptă</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="374"/>
        <source>Cooperation</source>
        <translation>Colaborare</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="393"/>
        <source>Connect to &quot;%1&quot; failed</source>
        <translation>Conectarea la &quot;%1&quot; a eșuat</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="418"/>
        <source>Unable to collaborate</source>
        <translation>Nu se poate colabora</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="419"/>
        <source>Failed to run process!</source>
        <translation>Eșecul procesului!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="441"/>
        <source>Connection successful, coordinating with  &quot;%1&quot;</source>
        <translation>Conexiunea a reușit, se coordonează cu &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="449"/>
        <source>&quot;%1&quot; has rejected your request for collaboration</source>
        <translation>&quot;%1&quot; a respins cererea ta de colaborare</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="459"/>
        <source>&quot;%1&quot; is connecting with other devices</source>
        <translation>&quot;%1&quot; se conectează cu alte dispozitive</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="503"/>
        <source>The connection request sent to you by &quot;%1&quot; was interrupted due to a timeout</source>
        <translation>Cererea de conexiune trimisă de &quot;%1&quot; a fost întreruptă din cauza unui timeout</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="513"/>
        <source>The other party does not confirm, please try again later</source>
        <translation>Partenerul nu confirmă, vă rugăm să încercați din nou mai târziu</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="524"/>
        <source>The other party has cancelled the connection request !</source>
        <translation>Partenerul a anulat cererea de conexiune !</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="528"/>
        <source>connect failed</source>
        <translation>conexiunea a eșuat</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="538"/>
        <source>Network not connected, file delivery failed this time.                               Please connect to the network and try again!</source>
        <translation>Rețeaua nu este conectată, livrarea fișierului a eșuat în această rundă. Vă rugăm să vă conectați la rețea și să încercați din nou!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="545"/>
        <source>File transfer failed</source>
        <translation>Tranziția fișierului a eșuat</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="547"/>
        <source>Network not connected, file delivery failed this time.                                           Please connect to the network and try again!</source>
        <translation>Rețeaua nu este conectată, livrarea fișierului a eșuat în această rundă. Vă rugăm să vă conectați la rețea și să încercați din nou!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="562"/>
        <source>Network exception</source>
        <translation>Excepție de rețea</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="563"/>
        <source>Please check the network &quot;%1&quot;</source>
        <translation>Vă rugăm să verificați rețeaua &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ShareHelperPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="103"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="109"/>
        <source>Cooperation</source>
        <translation>Colaborare</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="200"/>
        <source>Connection successful, coordinating with &quot;%1&quot;</source>
        <translation>Conexiunea a reușit, se coordonează cu &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>cooperation_core::TransferHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="433"/>
        <source>Connect to &quot;%1&quot; failed</source>
        <translation>Conexiunea către &quot;%1&quot; a eșuat</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="458"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="609"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="683"/>
        <source>File read/write exception</source>
        <translation>Excepție de citire/scriere a fișierului</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="579"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="630"/>
        <source>The other party has canceled the file transfer</source>
        <translation>Partenerul a anulat transferul de fișiere</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="478"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="626"/>
        <source>File sent successfully</source>
        <translation>Fișierul a fost trimis cu succes</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="168"/>
        <source>View transfer history</source>
        <translation>Vizualizați istoricul transferului</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="177"/>
        <source>Send files</source>
        <translation>Trimiteți fișiere</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="302"/>
        <source>The other party did not receive, the files failed to send</source>
        <translation>Partenerul nu a primit, fișierele au eșuat în trimitere</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="332"/>
        <source>Cancel</source>
        <translation>Anulare</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="335"/>
        <source>File receiving %1% | Remaining time %2</source>
        <translation>Recepția fișierului %1% | Timp rămas %2</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="342"/>
        <source>Sending files to &quot;%1&quot;</source>
        <translation>Trimiteți fișiere către &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="342"/>
        <source>Receiving files from &quot;%1&quot;</source>
        <translation>Recepția fișierelor de la &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="399"/>
        <source>Reject</source>
        <translation>Respinge</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="400"/>
        <source>Accept</source>
        <translation>Acceptă</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="401"/>
        <source>Close</source>
        <translation>Închide</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="394"/>
        <source>&quot;%1&quot; send some files to you</source>
        <translation>&quot;%1&quot; trimite fișiere către tine</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="313"/>
        <source>View</source>
        <translation>Vizualizare</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="412"/>
        <source>The other party has cancelled the transfer request !</source>
        <translation>Partenerul a anulat cererea de transfer !</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="452"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="605"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="680"/>
        <source>Insufficient storage space, file delivery failed this time. Please clean up disk space and try again!</source>
        <translation>Spațiu de stocare insuficient, livrarea fișierelor a eșuat această dată. Vă rugăm să curățați spațiul pe disc și încercați din nou!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="455"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="607"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="677"/>
        <source>Network not connected, file delivery failed this time. Please connect to the network and try again!</source>
        <translation>Rețeaua nu este conectată, livrarea fișierelor a eșuat această dată. Vă rugăm să vă conectați la rețea și încercați din nou!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="554"/>
        <source>calculating</source>
        <translation>se calculează</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="563"/>
        <source>The other party rejects your request</source>
        <translation>Partenerul a respins cererea ta</translation>
    </message>
</context>
<context>
    <name>cooperation_core::TransferHelperPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="132"/>
        <source>File transfer</source>
        <translation>Tranzitie de fișiere</translation>
    </message>
</context>
<context>
    <name>cooperation_core::VncViewer</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/vncviewer.cpp" line="211"/>
        <location filename="../../src/lib/cooperation/core/gui/phone/vncviewer.cpp" line="213"/>
        <source>Disconnected</source>
        <translation>Deconectat</translation>
    </message>
</context>
<context>
    <name>cooperation_core::WaitConfirmWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="75"/>
        <source>File Transfer</source>
        <translation>Tranzitie de fișiere</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="91"/>
        <source>Wait for confirmation...</source>
        <translation>Așteptați confirmarea...</translation>
    </message>
</context>
<context>
    <name>cooperation_core::WorkspaceWidgetPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="52"/>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="53"/>
        <source>Please enter the device ip/name of the collaborator</source>
        <translation>Vă rugăm să introduceți IP-ul / numele dispozitivului colaboratorului</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="56"/>
        <source>Nearby Device</source>
        <translation>Dispozitiv apropiat</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="72"/>
        <source>Re-scan for devices</source>
        <translation>Rescanează dispozitivele</translation>
    </message>
</context>
<context>
    <name>cooperation_transfer::TransferHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/transfer/helper/transferhelper.cpp" line="105"/>
        <source>Send files</source>
        <translation>Trimite fișiere</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationMenuScene</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/menu/cooperationmenuscene.cpp" line="34"/>
        <source>File transfer</source>
        <translation>Tranzitie de fișiere</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationPlugin</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/cooperationplugin.cpp" line="64"/>
        <source>File transfer</source>
        <translation>Tranzitie de fișiere</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::FileTransferSettingsDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="154"/>
        <source>File transfer settings</source>
        <translation>Setări tranzitie de fișiere</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="171"/>
        <source>Everyone in the same LAN</source>
        <translation>Toți în același LAN</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="172"/>
        <source>Only those who are collaborating are allowed</source>
        <translation>Doar cei care colaborează sunt permisi</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="173"/>
        <source>Not allow</source>
        <translation>Nu este permis</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="178"/>
        <source>Allows the following users to send files to me</source>
        <translation>Permite următorilor utilizatori să trimită fișiere către mine</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="179"/>
        <source>File save location</source>
        <translation>Locul unde se salvează fișierul</translation>
    </message>
</context>
</TS>